import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;

/// Get current DateTime from [internet](https://worldtimeapi.org)
/// [timezone] Set a timezone. Use [Timezones]
/// if null will return a timezone from public client ip
Future<DateTime> dateTimeFromInternet({String timezone}) async {
  var response = await http.get(
      "https://worldtimeapi.org/api/${timezone != null ? 'timezone/$timezone' : 'ip'}");
  var json = jsonDecode(response.body);
  if (response.statusCode != 200) {
    throw HttpException(response.body, uri: response.request.url);
  }
  return DateTime.parse(json['datetime'] as String).toLocal();
}

class Timezones {
  static final String africaAbidjan = 'Africa/Abidjan';
  static final String africaAccra = 'Africa/Accra';
  static final String africaAlgiers = 'Africa/Algiers';
  static final String africaBissau = 'Africa/Bissau';
  static final String africaCairo = 'Africa/Cairo';
  static final String africaCasablanca = 'Africa/Casablanca';
  static final String africaCeuta = 'Africa/Ceuta';
  static final String africaElAaiun = 'Africa/El_Aaiun';
  static final String africaJohannesburg = 'Africa/Johannesburg';
  static final String africaJuba = 'Africa/Juba';
  static final String africaKhartoum = 'Africa/Khartoum';
  static final String africaLagos = 'Africa/Lagos';
  static final String africaMaputo = 'Africa/Maputo';
  static final String africaMonrovia = 'Africa/Monrovia';
  static final String africaNairobi = 'Africa/Nairobi';
  static final String africaNdjamena = 'Africa/Ndjamena';
  static final String africaSaoTome = 'Africa/Sao_Tome';
  static final String africaTripoli = 'Africa/Tripoli';
  static final String africaTunis = 'Africa/Tunis';
  static final String africaWindhoek = 'Africa/Windhoek';
  static final String americaAdak = 'America/Adak';
  static final String americaAnchorage = 'America/Anchorage';
  static final String americaAraguaina = 'America/Araguaina';
  static final String americaArgentinaBuenosAires =
      'America/Argentina/Buenos_Aires';
  static final String americaArgentinaCatamarca = 'America/Argentina/Catamarca';
  static final String americaArgentinaCordoba = 'America/Argentina/Cordoba';
  static final String americaArgentinaJujuy = 'America/Argentina/Jujuy';
  static final String americaArgentinaLaRioja = 'America/Argentina/La_Rioja';
  static final String americaArgentinaMendoza = 'America/Argentina/Mendoza';
  static final String americaArgentinaRioGallegos =
      'America/Argentina/Rio_Gallegos';
  static final String americaArgentinaSalta = 'America/Argentina/Salta';
  static final String americaArgentinaSanJuan = 'America/Argentina/San_Juan';
  static final String americaArgentinaSanLuis = 'America/Argentina/San_Luis';
  static final String americaArgentinaTucuman = 'America/Argentina/Tucuman';
  static final String americaArgentinaUshuaia = 'America/Argentina/Ushuaia';
  static final String americaAsuncion = 'America/Asuncion';
  static final String americaAtikokan = 'America/Atikokan';
  static final String americaBahia = 'America/Bahia';
  static final String americaBahiaBanderas = 'America/Bahia_Banderas';
  static final String americaBarbados = 'America/Barbados';
  static final String americaBelem = 'America/Belem';
  static final String americaBelize = 'America/Belize';
  static final String americaBlancSablon = 'America/Blanc-Sablon';
  static final String americaBoaVista = 'America/Boa_Vista';
  static final String americaBogota = 'America/Bogota';
  static final String americaBoise = 'America/Boise';
  static final String americaCambridgeBay = 'America/Cambridge_Bay';
  static final String americaCampoGrande = 'America/Campo_Grande';
  static final String americaCancun = 'America/Cancun';
  static final String americaCaracas = 'America/Caracas';
  static final String americaCayenne = 'America/Cayenne';
  static final String americaChicago = 'America/Chicago';
  static final String americaChihuahua = 'America/Chihuahua';
  static final String americaCostaRica = 'America/Costa_Rica';
  static final String americaCreston = 'America/Creston';
  static final String americaCuiaba = 'America/Cuiaba';
  static final String americaCuracao = 'America/Curacao';
  static final String americaDanmarkshavn = 'America/Danmarkshavn';
  static final String americaDawson = 'America/Dawson';
  static final String americaDawsonCreek = 'America/Dawson_Creek';
  static final String americaDenver = 'America/Denver';
  static final String americaDetroit = 'America/Detroit';
  static final String americaEdmonton = 'America/Edmonton';
  static final String americaEirunepe = 'America/Eirunepe';
  static final String americaElSalvador = 'America/El_Salvador';
  static final String americaFortNelson = 'America/Fort_Nelson';
  static final String americaFortaleza = 'America/Fortaleza';
  static final String americaGlaceBay = 'America/Glace_Bay';
  static final String americaGodthab = 'America/Godthab';
  static final String americaGooseBay = 'America/Goose_Bay';
  static final String americaGrandTurk = 'America/Grand_Turk';
  static final String americaGuatemala = 'America/Guatemala';
  static final String americaGuayaquil = 'America/Guayaquil';
  static final String americaGuyana = 'America/Guyana';
  static final String americaHalifax = 'America/Halifax';
  static final String americaHavana = 'America/Havana';
  static final String americaHermosillo = 'America/Hermosillo';
  static final String americaIndianaIndianapolis =
      'America/Indiana/Indianapolis';
  static final String americaIndianaKnox = 'America/Indiana/Knox';
  static final String americaIndianaMarengo = 'America/Indiana/Marengo';
  static final String americaIndianaPetersburg = 'America/Indiana/Petersburg';
  static final String americaIndianaTellCity = 'America/Indiana/Tell_City';
  static final String americaIndianaVevay = 'America/Indiana/Vevay';
  static final String americaIndianaVincennes = 'America/Indiana/Vincennes';
  static final String americaIndianaWinamac = 'America/Indiana/Winamac';
  static final String americaInuvik = 'America/Inuvik';
  static final String americaIqaluit = 'America/Iqaluit';
  static final String americaJamaica = 'America/Jamaica';
  static final String americaJuneau = 'America/Juneau';
  static final String americaKentuckyLouisville = 'America/Kentucky/Louisville';
  static final String americaKentuckyMonticello = 'America/Kentucky/Monticello';
  static final String americaLaPaz = 'America/La_Paz';
  static final String americaLima = 'America/Lima';
  static final String americaLosAngeles = 'America/Los_Angeles';
  static final String americaMaceio = 'America/Maceio';
  static final String americaManagua = 'America/Managua';
  static final String americaManaus = 'America/Manaus';
  static final String americaMartinique = 'America/Martinique';
  static final String americaMatamoros = 'America/Matamoros';
  static final String americaMazatlan = 'America/Mazatlan';
  static final String americaMenominee = 'America/Menominee';
  static final String americaMerida = 'America/Merida';
  static final String americaMetlakatla = 'America/Metlakatla';
  static final String americaMexicoCity = 'America/Mexico_City';
  static final String americaMiquelon = 'America/Miquelon';
  static final String americaMoncton = 'America/Moncton';
  static final String americaMonterrey = 'America/Monterrey';
  static final String americaMontevideo = 'America/Montevideo';
  static final String americaNassau = 'America/Nassau';
  static final String americaNewYork = 'America/New_York';
  static final String americaNipigon = 'America/Nipigon';
  static final String americaNome = 'America/Nome';
  static final String americaNoronha = 'America/Noronha';
  static final String americaNorthDakotaBeulah = 'America/North_Dakota/Beulah';
  static final String americaNorthDakotaCenter = 'America/North_Dakota/Center';
  static final String americaNorthDakotaNewSalem =
      'America/North_Dakota/New_Salem';
  static final String americaOjinaga = 'America/Ojinaga';
  static final String americaPanama = 'America/Panama';
  static final String americaPangnirtung = 'America/Pangnirtung';
  static final String americaParamaribo = 'America/Paramaribo';
  static final String americaPhoenix = 'America/Phoenix';
  static final String americaPortauPrince = 'America/Port-au-Prince';
  static final String americaPortofSpain = 'America/Port_of_Spain';
  static final String americaPortoVelho = 'America/Porto_Velho';
  static final String americaPuertoRico = 'America/Puerto_Rico';
  static final String americaPuntaArenas = 'America/Punta_Arenas';
  static final String americaRainyRiver = 'America/Rainy_River';
  static final String americaRankinInlet = 'America/Rankin_Inlet';
  static final String americaRecife = 'America/Recife';
  static final String americaRegina = 'America/Regina';
  static final String americaResolute = 'America/Resolute';
  static final String americaRioBranco = 'America/Rio_Branco';
  static final String americaSantarem = 'America/Santarem';
  static final String americaSantiago = 'America/Santiago';
  static final String americaSantoDomingo = 'America/Santo_Domingo';
  static final String americaSaoPaulo = 'America/Sao_Paulo';
  static final String americaScoresbysund = 'America/Scoresbysund';
  static final String americaSitka = 'America/Sitka';
  static final String americaStJohns = 'America/St_Johns';
  static final String americaSwiftCurrent = 'America/Swift_Current';
  static final String americaTegucigalpa = 'America/Tegucigalpa';
  static final String americaThule = 'America/Thule';
  static final String americaThunderBay = 'America/Thunder_Bay';
  static final String americaTijuana = 'America/Tijuana';
  static final String americaToronto = 'America/Toronto';
  static final String americaVancouver = 'America/Vancouver';
  static final String americaWhitehorse = 'America/Whitehorse';
  static final String americaWinnipeg = 'America/Winnipeg';
  static final String americaYakutat = 'America/Yakutat';
  static final String americaYellowknife = 'America/Yellowknife';
  static final String antarcticaCasey = 'Antarctica/Casey';
  static final String antarcticaDavis = 'Antarctica/Davis';
  static final String antarcticaDumontDUrville = 'Antarctica/DumontDUrville';
  static final String antarcticaMacquarie = 'Antarctica/Macquarie';
  static final String antarcticaMawson = 'Antarctica/Mawson';
  static final String antarcticaPalmer = 'Antarctica/Palmer';
  static final String antarcticaRothera = 'Antarctica/Rothera';
  static final String antarcticaSyowa = 'Antarctica/Syowa';
  static final String antarcticaTroll = 'Antarctica/Troll';
  static final String antarcticaVostok = 'Antarctica/Vostok';
  static final String asiaAlmaty = 'Asia/Almaty';
  static final String asiaAmman = 'Asia/Amman';
  static final String asiaAnadyr = 'Asia/Anadyr';
  static final String asiaAqtau = 'Asia/Aqtau';
  static final String asiaAqtobe = 'Asia/Aqtobe';
  static final String asiaAshgabat = 'Asia/Ashgabat';
  static final String asiaAtyrau = 'Asia/Atyrau';
  static final String asiaBaghdad = 'Asia/Baghdad';
  static final String asiaBaku = 'Asia/Baku';
  static final String asiaBangkok = 'Asia/Bangkok';
  static final String asiaBarnaul = 'Asia/Barnaul';
  static final String asiaBeirut = 'Asia/Beirut';
  static final String asiaBishkek = 'Asia/Bishkek';
  static final String asiaBrunei = 'Asia/Brunei';
  static final String asiaChita = 'Asia/Chita';
  static final String asiaChoibalsan = 'Asia/Choibalsan';
  static final String asiaColombo = 'Asia/Colombo';
  static final String asiaDamascus = 'Asia/Damascus';
  static final String asiaDhaka = 'Asia/Dhaka';
  static final String asiaDili = 'Asia/Dili';
  static final String asiaDubai = 'Asia/Dubai';
  static final String asiaDushanbe = 'Asia/Dushanbe';
  static final String asiaFamagusta = 'Asia/Famagusta';
  static final String asiaGaza = 'Asia/Gaza';
  static final String asiaHebron = 'Asia/Hebron';
  static final String asiaHoChiMinh = 'Asia/Ho_Chi_Minh';
  static final String asiaHongKong = 'Asia/Hong_Kong';
  static final String asiaHovd = 'Asia/Hovd';
  static final String asiaIrkutsk = 'Asia/Irkutsk';
  static final String asiaJakarta = 'Asia/Jakarta';
  static final String asiaJayapura = 'Asia/Jayapura';
  static final String asiaJerusalem = 'Asia/Jerusalem';
  static final String asiaKabul = 'Asia/Kabul';
  static final String asiaKamchatka = 'Asia/Kamchatka';
  static final String asiaKarachi = 'Asia/Karachi';
  static final String asiaKathmandu = 'Asia/Kathmandu';
  static final String asiaKhandyga = 'Asia/Khandyga';
  static final String asiaKolkata = 'Asia/Kolkata';
  static final String asiaKrasnoyarsk = 'Asia/Krasnoyarsk';
  static final String asiaKualaLumpur = 'Asia/Kuala_Lumpur';
  static final String asiaKuching = 'Asia/Kuching';
  static final String asiaMacau = 'Asia/Macau';
  static final String asiaMagadan = 'Asia/Magadan';
  static final String asiaMakassar = 'Asia/Makassar';
  static final String asiaManila = 'Asia/Manila';
  static final String asiaNicosia = 'Asia/Nicosia';
  static final String asiaNovokuznetsk = 'Asia/Novokuznetsk';
  static final String asiaNovosibirsk = 'Asia/Novosibirsk';
  static final String asiaOmsk = 'Asia/Omsk';
  static final String asiaOral = 'Asia/Oral';
  static final String asiaPontianak = 'Asia/Pontianak';
  static final String asiaPyongyang = 'Asia/Pyongyang';
  static final String asiaQatar = 'Asia/Qatar';
  static final String asiaQostanay = 'Asia/Qostanay';
  static final String asiaQyzylorda = 'Asia/Qyzylorda';
  static final String asiaRiyadh = 'Asia/Riyadh';
  static final String asiaSakhalin = 'Asia/Sakhalin';
  static final String asiaSamarkand = 'Asia/Samarkand';
  static final String asiaSeoul = 'Asia/Seoul';
  static final String asiaShanghai = 'Asia/Shanghai';
  static final String asiaSingapore = 'Asia/Singapore';
  static final String asiaSrednekolymsk = 'Asia/Srednekolymsk';
  static final String asiaTaipei = 'Asia/Taipei';
  static final String asiaTashkent = 'Asia/Tashkent';
  static final String asiaTbilisi = 'Asia/Tbilisi';
  static final String asiaTehran = 'Asia/Tehran';
  static final String asiaThimphu = 'Asia/Thimphu';
  static final String asiaTokyo = 'Asia/Tokyo';
  static final String asiaTomsk = 'Asia/Tomsk';
  static final String asiaUlaanbaatar = 'Asia/Ulaanbaatar';
  static final String asiaUrumqi = 'Asia/Urumqi';
  static final String asiaUstNera = 'Asia/Ust-Nera';
  static final String asiaVladivostok = 'Asia/Vladivostok';
  static final String asiaYakutsk = 'Asia/Yakutsk';
  static final String asiaYangon = 'Asia/Yangon';
  static final String asiaYekaterinburg = 'Asia/Yekaterinburg';
  static final String asiaYerevan = 'Asia/Yerevan';
  static final String atlanticAzores = 'Atlantic/Azores';
  static final String atlanticBermuda = 'Atlantic/Bermuda';
  static final String atlanticCanary = 'Atlantic/Canary';
  static final String atlanticCapeVerde = 'Atlantic/Cape_Verde';
  static final String atlanticFaroe = 'Atlantic/Faroe';
  static final String atlanticMadeira = 'Atlantic/Madeira';
  static final String atlanticReykjavik = 'Atlantic/Reykjavik';
  static final String atlanticSouthGeorgia = 'Atlantic/South_Georgia';
  static final String atlanticStanley = 'Atlantic/Stanley';
  static final String australiaAdelaide = 'Australia/Adelaide';
  static final String australiaBrisbane = 'Australia/Brisbane';
  static final String australiaBrokenHill = 'Australia/Broken_Hill';
  static final String australiaCurrie = 'Australia/Currie';
  static final String australiaDarwin = 'Australia/Darwin';
  static final String australiaEucla = 'Australia/Eucla';
  static final String australiaHobart = 'Australia/Hobart';
  static final String australiaLindeman = 'Australia/Lindeman';
  static final String australiaLordHowe = 'Australia/Lord_Howe';
  static final String australiaMelbourne = 'Australia/Melbourne';
  static final String australiaPerth = 'Australia/Perth';
  static final String australiaSydney = 'Australia/Sydney';
  static final String cET = 'CET';
  static final String cST6CDT = 'CST6CDT';
  static final String eET = 'EET';
  static final String eST = 'EST';
  static final String eST5EDT = 'EST5EDT';
  static final String etcGMT = 'Etc/GMT';
  static final String europeAmsterdam = 'Europe/Amsterdam';
  static final String europeAndorra = 'Europe/Andorra';
  static final String europeAstrakhan = 'Europe/Astrakhan';
  static final String europeAthens = 'Europe/Athens';
  static final String europeBelgrade = 'Europe/Belgrade';
  static final String europeBerlin = 'Europe/Berlin';
  static final String europeBrussels = 'Europe/Brussels';
  static final String europeBucharest = 'Europe/Bucharest';
  static final String europeBudapest = 'Europe/Budapest';
  static final String europeChisinau = 'Europe/Chisinau';
  static final String europeCopenhagen = 'Europe/Copenhagen';
  static final String europeDublin = 'Europe/Dublin';
  static final String europeGibraltar = 'Europe/Gibraltar';
  static final String europeHelsinki = 'Europe/Helsinki';
  static final String europeIstanbul = 'Europe/Istanbul';
  static final String europeKaliningrad = 'Europe/Kaliningrad';
  static final String europeKiev = 'Europe/Kiev';
  static final String europeKirov = 'Europe/Kirov';
  static final String europeLisbon = 'Europe/Lisbon';
  static final String europeLondon = 'Europe/London';
  static final String europeLuxembourg = 'Europe/Luxembourg';
  static final String europeMadrid = 'Europe/Madrid';
  static final String europeMalta = 'Europe/Malta';
  static final String europeMinsk = 'Europe/Minsk';
  static final String europeMonaco = 'Europe/Monaco';
  static final String europeMoscow = 'Europe/Moscow';
  static final String europeOslo = 'Europe/Oslo';
  static final String europeParis = 'Europe/Paris';
  static final String europePrague = 'Europe/Prague';
  static final String europeRiga = 'Europe/Riga';
  static final String europeRome = 'Europe/Rome';
  static final String europeSamara = 'Europe/Samara';
  static final String europeSaratov = 'Europe/Saratov';
  static final String europeSimferopol = 'Europe/Simferopol';
  static final String europeSofia = 'Europe/Sofia';
  static final String europeStockholm = 'Europe/Stockholm';
  static final String europeTallinn = 'Europe/Tallinn';
  static final String europeTirane = 'Europe/Tirane';
  static final String europeUlyanovsk = 'Europe/Ulyanovsk';
  static final String europeUzhgorod = 'Europe/Uzhgorod';
  static final String europeVienna = 'Europe/Vienna';
  static final String europeVilnius = 'Europe/Vilnius';
  static final String europeVolgograd = 'Europe/Volgograd';
  static final String europeWarsaw = 'Europe/Warsaw';
  static final String europeZaporozhye = 'Europe/Zaporozhye';
  static final String europeZurich = 'Europe/Zurich';
  static final String hST = 'HST';
  static final String indianChagos = 'Indian/Chagos';
  static final String indianChristmas = 'Indian/Christmas';
  static final String indianCocos = 'Indian/Cocos';
  static final String indianKerguelen = 'Indian/Kerguelen';
  static final String indianMahe = 'Indian/Mahe';
  static final String indianMaldives = 'Indian/Maldives';
  static final String indianMauritius = 'Indian/Mauritius';
  static final String indianReunion = 'Indian/Reunion';
  static final String mET = 'MET';
  static final String mST = 'MST';
  static final String mST7MDT = 'MST7MDT';
  static final String pST8PDT = 'PST8PDT';
  static final String pacificApia = 'Pacific/Apia';
  static final String pacificAuckland = 'Pacific/Auckland';
  static final String pacificBougainville = 'Pacific/Bougainville';
  static final String pacificChatham = 'Pacific/Chatham';
  static final String pacificChuuk = 'Pacific/Chuuk';
  static final String pacificEaster = 'Pacific/Easter';
  static final String pacificEfate = 'Pacific/Efate';
  static final String pacificEnderbury = 'Pacific/Enderbury';
  static final String pacificFakaofo = 'Pacific/Fakaofo';
  static final String pacificFiji = 'Pacific/Fiji';
  static final String pacificFunafuti = 'Pacific/Funafuti';
  static final String pacificGalapagos = 'Pacific/Galapagos';
  static final String pacificGambier = 'Pacific/Gambier';
  static final String pacificGuadalcanal = 'Pacific/Guadalcanal';
  static final String pacificGuam = 'Pacific/Guam';
  static final String pacificHonolulu = 'Pacific/Honolulu';
  static final String pacificKiritimati = 'Pacific/Kiritimati';
  static final String pacificKosrae = 'Pacific/Kosrae';
  static final String pacificKwajalein = 'Pacific/Kwajalein';
  static final String pacificMajuro = 'Pacific/Majuro';
  static final String pacificMarquesas = 'Pacific/Marquesas';
  static final String pacificNauru = 'Pacific/Nauru';
  static final String pacificNiue = 'Pacific/Niue';
  static final String pacificNorfolk = 'Pacific/Norfolk';
  static final String pacificNoumea = 'Pacific/Noumea';
  static final String pacificPagoPago = 'Pacific/Pago_Pago';
  static final String pacificPalau = 'Pacific/Palau';
  static final String pacificPitcairn = 'Pacific/Pitcairn';
  static final String pacificPohnpei = 'Pacific/Pohnpei';
  static final String pacificPortMoresby = 'Pacific/Port_Moresby';
  static final String pacificRarotonga = 'Pacific/Rarotonga';
  static final String pacificTahiti = 'Pacific/Tahiti';
  static final String pacificTarawa = 'Pacific/Tarawa';
  static final String pacificTongatapu = 'Pacific/Tongatapu';
  static final String pacificWake = 'Pacific/Wake';
  static final String pacificWallis = 'Pacific/Wallis';
  static final String wET = 'WET';
}
